#ifndef EA_TFT_DEF_H
#define EA_TFT_DEF_H

//-------------------------------------------------------------------------------------------------
// TFT SPI-Defines
#define TFT_PORT spi1
#define TFT_SCK   10  // Pin 14
#define TFT_TX    11  // Pin 15
#define TFT_RX    12  // Pin 16
#define TFT_CS    13  // Pin 17
#define TFT_RS    6   // Pin 9
#define TFT_RES   7   // Pin 10

//-------------------------------------------------------------------------------------------------
// supported TFT-modules
#define EA_TFT009   1
#define EA_TFT015   2
#define EA_TFT020   3
#define EA_TFT028   4
#define EA_TFT035   5

//------------------------------------------------------------------------------
// available Fonts
#define FONT_6X8    1
#define FONT_7X12   2
#define FONT_8X16   3
#define FONT_30X38  4   // only numbers and ':'

//-------------------------------------------------------------------------------------------------
// structures for BMP-File ant Font 

#pragma pack(push,1)

typedef struct
{                       // BITMAPFILEHEADER 
  uint16_t bfType;           // the file type must be BM
  uint32_t bfSize;           // the size in bytes of the bitmap file
  uint16_t bfReserved1;      // reserved must be zero.
  uint16_t bfReserved2;      // reserved must be zero.
  uint32_t bfOffBits;        // the offset in bytes from the beginning of the BITMAPFILEHEADER structure to the bitmap bits

                        // BITMAPINFOHEADER
  uint32_t biSize;           // specifies the number of bytes required by the structure
  int32_t  biWidth;          // specifies the width of the bitmap in pixels
  int32_t  biHeight;         // specifies the height of the bitmap in pixels
  uint16_t biPlanes;         // this value must be set to 1
  uint16_t biBitCount;       // specifies the number of bits per pixel
  uint32_t biCompression;    // specifies the compression
  uint32_t biSizeImage;      // specifies the size in bytes of the image
  int32_t  biXPelsPerMeter;  // specifies the horizontal resolution in pixels per meter
  int32_t  biYPelsPerMeter;  // specifies the vertical resolution in pixels per meter
  uint32_t biClrUsed;        // specifies the number of color indices in the color table that are actually used by the bitmap
  uint32_t biClrImportant;   // specifies the number of color indices that are considered important for displaying the bitmap
} BMP_HDR;

typedef struct
{ uint8_t F;			    // 'F' first 2 bytes are always FH
  uint8_t H;			    // 'H' for FONT horizontal
  uint8_t first;		  // first defined code
  uint8_t last;		    // last  defined code
  uint8_t width;		  // width  of character in dots
  uint8_t height;		  // height of character in dots
  uint8_t bytewidth;  // width  of character in bytes
  uint8_t bytechar;	  // number of bytes needed for each character
  uint8_t dat[0];		  // begin  of character data
} FH_FONT;

#pragma pack(pop)

//------------------------------------------------------------------------------

#define LO(w)			( (w)     & 0xFF)
#define HI(w)			(((w)>>8) & 0xFF)

#define RGB565(r,g,b)   ( (((r)&0xF8) << 8) | (((g)&0xFC) << 3) | ((b)>>3) )

#define BLACK   0x0000
#define WHITE   0xFFFF
#define RED     RGB565(255,0,0)
#define GREEN   RGB565(0,255,0)
#define BLUE    RGB565(0,0,255)
#define CYAN    RGB565(0,255,255)
#define MAGENTA RGB565(255,0,255)
#define YELLOW  RGB565(255,255,0)

//------------------------------------------------------------------------------

#endif  /* EA_TFT_DEF_H */